@@ -1,20 +1,9 @@
-from typing import List, Optional
-
 import attr
+
+from typing import List, Optional
+from secoda_common.models.tag import Tag
 from marshmallow_annotations.ext.attrs import AttrsSchema
 
-@attr.s(auto_attribs=True, kw_only=True)
-class Tag:
-    tag_type: str
-    tag_name: str
-
-
-class TagSchema(AttrsSchema):
-    class Meta:
-        target = Tag
-        register_as_scheme = True
-
-
 @attr.s(auto_attribs=True, kw_only=True)
 class Badge:
     badge_name: str = attr.ib()
