@@ -83,7 +83,7 @@ class Column:
     badges: Optional[List[Badge]] = []
     tags: Optional[List[Tag]] = []
     is_pk: Optional[bool] = None
-    column_reference: Optional[ColumnReference] = None
+    column_references: Optional[List[ColumnReference]] = None
 
 
 class ColumnSchema(AttrsSchema):
